@@ -2,7 +2,7 @@ package Test::DBIx::Class::Schema;
 {
   $Test::DBIx::Class::Schema::DIST = 'Test-DBIx-Class-Schema';
 }
-$Test::DBIx::Class::Schema::VERSION = '1.0.8';
+$Test::DBIx::Class::Schema::VERSION = '1.0.9';
 # vim: ts=8 sts=4 et sw=4 sr sta
 use strict;
 use warnings;
@@ -300,7 +300,7 @@ Test::DBIx::Class::Schema - DBIx::Class schema sanity checking tests
 
 =head1 VERSION
 
-version 1.0.8
+version 1.0.9
 
 =head1 SYNOPSIS
 
@@ -417,13 +417,6 @@ L<DBIx::Class>,
 L<Test::More>,
 L<Test::Aggregate>
 
-=head1 CONTRIBUTORS
-
-Gianni Ceccarelli C<< <dakkar@thenautilus.net> >>,
-Darius Jokilehto,
-Jason Tang C<< <tang.jason.ch@gmail.com> >>,
-Rupert Lane (L<https://github.com/rupertl>)
-
 =head1 AUTHOR
 
 Chisel Wright <chisel@chizography.net>
@@ -435,4 +428,48 @@ This software is copyright (c) 2015 by Chisel Wright.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTORS
+
+=for stopwords Chisel Wright Darius Jokilehto Dave Cross Jason Tang Rupert Lane
+
+=over 4
+
+=item *
+
+Chisel <chisel.wright@net-a-porter.com>
+
+=item *
+
+Chisel <chisel@chizography.net>
+
+=item *
+
+Chisel Wright <chisel.wright@net-a-porter.com>
+
+=item *
+
+Chisel Wright <chisel@cleavag.es>
+
+=item *
+
+Chisel Wright <chisel@herlpacker.co.uk>
+
+=item *
+
+Darius Jokilehto <darius.jokilehto@net-a-porter.com>
+
+=item *
+
+Dave Cross <davidc@broadbean.com>
+
+=item *
+
+Jason Tang <tang.jason.ch@gmail.com>
+
+=item *
+
+Rupert Lane <rupert@rupert-lane.org>
+
+=back
+
 =cut
